summaryrefslogtreecommitdiffstats
path: root/libtdegames/kchatbase.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:32:59 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:32:59 -0600
commit2f84d0e2d3d4252e6aee24aceafa45dbdb7f4d1d (patch)
treeea24a96bad3bb7356ec1a2dca2a1338692d79745 /libtdegames/kchatbase.h
parentd6f3812c8d969a673b420beca2482804177704fb (diff)
downloadtdegames-2f84d0e2d3d4252e6aee24aceafa45dbdb7f4d1d.tar.gz
tdegames-2f84d0e2d3d4252e6aee24aceafa45dbdb7f4d1d.zip
Rename KCModule, KConfig, KIO, KServer, and KSocket to avoid conflicts with KDE4
Diffstat (limited to 'libtdegames/kchatbase.h')
-rw-r--r--libtdegames/kchatbase.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/libtdegames/kchatbase.h b/libtdegames/kchatbase.h
index 5c28f6a7..4c264472 100644
--- a/libtdegames/kchatbase.h
+++ b/libtdegames/kchatbase.h
@@ -27,7 +27,7 @@
#include <kdemacros.h>
class TQListBoxItem;
-class KConfig;
+class TDEConfig;
class KChatBaseTextPrivate;
@@ -361,22 +361,22 @@ public:
const TQFont& systemMessageFont() const;
/**
* Save the configuration of the dialog to a KConfig object. If
* the supplied KConfig pointer is NULL then kapp->config() is used
* instead (and the group is changed to "KChatBase") butr the current
* group is restored at the end.
* @param conf A pointer to the KConfig object to save the config
* to. If you use 0 then kapp->config() is used and the group is changed
* to "KChatBase" (the current group is restored at the end).
**/
- virtual void saveConfig(KConfig* conf = 0);
+ virtual void saveConfig(TDEConfig* conf = 0);
/**
* Read the configuration from a KConfig object. If the pointer is
* NULL kapp->config() is used and the group is changed to "KChatBase".
* The current KConfig::group is restored after this call.
**/
- virtual void readConfig(KConfig* conf = 0);
+ virtual void readConfig(TDEConfig* conf = 0);
/**
* Set the maximum number of items in the list. If the number of item
@@ -361,22 +361,22 @@ public:
const TQFont& systemMessageFont() const;
/**
- * Save the configuration of the dialog to a KConfig object. If
- * the supplied KConfig pointer is NULL then kapp->config() is used
+ * Save the configuration of the dialog to a TDEConfig object. If
+ * the supplied TDEConfig pointer is NULL then kapp->config() is used
* instead (and the group is changed to "KChatBase") butr the current
* group is restored at the end.
@@ -361,22 +361,22 @@ public:
* instead (and the group is changed to "KChatBase") butr the current
* group is restored at the end.
- * @param conf A pointer to the KConfig object to save the config
+ * @param conf A pointer to the TDEConfig object to save the config
* to. If you use 0 then kapp->config() is used and the group is changed
* to "KChatBase" (the current group is restored at the end).
@@ -361,22 +361,22 @@ public:
/**
- * Read the configuration from a KConfig object. If the pointer is
+ * Read the configuration from a TDEConfig object. If the pointer is
* NULL kapp->config() is used and the group is changed to "KChatBase".
@@ -361,22 +361,22 @@ public:
* NULL kapp->config() is used and the group is changed to "KChatBase".
- * The current KConfig::group is restored after this call.
+ * The current TDEConfig::group is restored after this call.
**/